GDAPS - Generic Django Apps Plugin System — GDAPS documentation

# GDAPS - Generic Django Apps Plugin System

Welcome to the GDAPS documentation!

GDAPS is a plugin system that can be added to Django, to create applications that can be extended via plugins later.

Note

As of v0.7.0, Vue.js support was dropped, in favour of the new template rendering plugin system.

Table of Contents

- Introduction
  - GDAPS working modes
- Installation
  - Project name
  - Project title
  - URL handling
  - Logging
- Usage
  - Creating plugins
- Routers Django Rest Framework
- API
  - Interfaces/Implementations
  - Plugin configuration and metadata
  - PluginManager
  - Templates
  - Helper functions
- Contributing
  - Code style

# License

I’d like to give back what I received from many Open Source software packages, and keep this library as open as possible, and it should stay this way. GDAPS is licensed under the BSD License (BSD).